===========
ETOS Client
===========

.. image:: https://img.shields.io/badge/Stage-Sandbox-yellow.svg
  :target: https://github.com/eiffel-community/community/blob/master/PROJECT_LIFECYCLE.md#stage-sandbox

ETOS (Eiffel Test Orchestration System) Client


Description
===========

ETOS Client is the client tool for executing test suites within ETOS.


Features
========

- Easy to get started with.
- Powerful integration with ETOS.
- Interacts well with automation server.


Installation
============

Install the project by running:

   pip install etos_client


Examples
========

.. code-block::

   etos_client -i pkg:docker/etos/suite_runner@1.0.0 -s http://mytestsuite.json


Contribute
==========

- Issue Tracker: https://github.com/eiffel-community/etos/issues
- Source Code: https://github.com/eiffel-community/etos-client


Support
=======

If you are having issues, please let us know.
There is a mailing list at: etos-maintainers@googlegroups.com or just write an Issue.
